@@ -1,65 +1,17 @@
-# -*- coding: utf-8 -*-
-#
-# spec.py
-#
-# Copyright (C) 2012, 2013 Steve Canny scanny@cisco.com
-#
-# This module is part of python-pptx and is released under
-# the MIT License: http://www.opensource.org/licenses/mit-license.php
+# encoding: utf-8
 
 """
-Constant values from the ECMA-376 spec that are needed for XML generation and
-packaging, and a utility function or two for accessing some of them.
+Constant values from the ISO/IEC 29500 spec that are needed for XML
+generation and packaging, and a utility function or two for accessing some of
+them.
 """
 
-from constants import (
-    MSO_AUTO_SHAPE_TYPE as MAST, MSO, PP, TEXT_ALIGN_TYPE as TAT,
-    TEXT_ANCHORING_TYPE as TANC
+from __future__ import absolute_import
+
+from pptx.constants import (
+    MSO_AUTO_SHAPE_TYPE as MAST, PP, TEXT_ALIGN_TYPE as TAT
 )
-
-
-class VerticalAnchor(object):
-    """
-    Mappings between ``MsoVerticalAnchor`` values used in the API and
-    ``ST_TextAnchoringType`` values used in the XML. ``MsoVerticalAnchor``
-    values are like ``MSO.ANCHOR_MIDDLE``.
-    """
-    _mapping = {
-        MSO.ANCHOR_TOP:    TANC.TOP,
-        MSO.ANCHOR_MIDDLE: TANC.MIDDLE,
-        MSO.ANCHOR_BOTTOM: TANC.BOTTOM
-    }
-
-    @classmethod
-    def from_text_anchoring_type(cls, text_anchoring_type):
-        """
-        Map an ``ST_TextAnchoringType`` value (e.g. ``TANC.TOP`` or
-        ``'t'``) to an MsoVerticalAnchor value (e.g. ``MSO.ANCHOR_TOP``).
-        Returns |None| if *text_anchoring_type* is |None|.
-        """
-        if text_anchoring_type is None:
-            return None
-        for vertical_anchor, tanc in cls._mapping.iteritems():
-            if tanc == text_anchoring_type:
-                return vertical_anchor
-        tmpl = "no vertical anchor type for ST_TextAnchoringType '%s'"
-        raise KeyError(tmpl % text_anchoring_type)
-
-    @classmethod
-    def to_text_anchoring_type(cls, vertical_anchor):
-        """
-        Map an ``MsoVerticalAnchor`` value (e.g. ``MSO.ANCHOR_MIDDLE``) to an
-        ``ST_TextAnchoringType`` value (e.g. ``TANC.MIDDLE`` or ``'ctr'``).
-        Returns None if *vertical_anchor* is None.
-        """
-        if vertical_anchor is None:
-            return None
-        try:
-            text_anchoring_type = cls._mapping[vertical_anchor]
-        except KeyError:
-            tmpl = "no ST_TextAnchoringType value for vertical_anchor '%s'"
-            raise KeyError(tmpl % vertical_anchor)
-        return text_anchoring_type
+from pptx.opc.constants import CONTENT_TYPE as CT, RELATIONSHIP_TYPE as RT
 
 
 class ParagraphAlignment(object):
@@ -605,7 +557,7 @@ autoshape_types = {
     },
     MAST.FOLDED_CORNER: {
         'basename': 'Folded Corner',
-        'prst':     'folderCorner',
+        'prst':     'foldedCorner',
         'avLst':    ()
     },
     MAST.FRAME: {
@@ -1544,156 +1496,19 @@ PTS_HASRELS_ALWAYS = 'always'
 PTS_HASRELS_NEVER = 'never'
 PTS_HASRELS_OPTIONAL = 'optional'
 
-CT_CHART = (
-    'application/vnd.openxmlformats-officedocument.drawingml.chart+xml')
-CT_COMMENT_AUTHORS = (
-    'application/vnd.openxmlformats-officedocument.presentationml.commentAuth'
-    'ors+xml')
-CT_COMMENTS = (
-    'application/vnd.openxmlformats-officedocument.presentationml.comments+xm'
-    'l')
-CT_CORE_PROPS = (
-    'application/vnd.openxmlformats-package.core-properties+xml')
-CT_CUSTOM_PROPS = (
-    'application/vnd.openxmlformats-officedocument.custom-properties+xml'
-)
-CT_CUSTOM_XML = (
-    'application/xml'
-)
-CT_CUSTOM_XML_PROPS = (
-    'application/vnd.openxmlformats-officedocument.customXmlProperties+xml'
-)
-CT_EXCEL_XLSX = (
-    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet')
-CT_EXTENDED_PROPS = (
-    'application/vnd.openxmlformats-officedocument.extended-properties+xml')
-CT_HANDOUT_MASTER = (
-    'application/vnd.openxmlformats-officedocument.presentationml.handoutMast'
-    'er+xml')
-CT_NOTES_MASTER = (
-    'application/vnd.openxmlformats-officedocument.presentationml.notesMaster'
-    '+xml')
-CT_NOTES_SLIDE = (
-    'application/vnd.openxmlformats-officedocument.presentationml.notesSlide+'
-    'xml')
-CT_PRES_PROPS = (
-    'application/vnd.openxmlformats-officedocument.presentationml.presProps+x'
-    'ml')
-CT_PRESENTATION = (
-    'application/vnd.openxmlformats-officedocument.presentationml.presentatio'
-    'n.main+xml')
-CT_PRINTER_SETTINGS = (
-    'application/vnd.openxmlformats-officedocument.presentationml.printerSett'
-    'ings')
-CT_SLIDE = (
-    'application/vnd.openxmlformats-officedocument.presentationml.slide+xml')
-CT_SLIDE_LAYOUT = (
-    'application/vnd.openxmlformats-officedocument.presentationml.slideLayout'
-    '+xml')
-CT_SLIDE_MASTER = (
-    'application/vnd.openxmlformats-officedocument.presentationml.slideMaster'
-    '+xml')
-CT_SLIDESHOW = (
-    'application/vnd.openxmlformats-officedocument.presentationml.slideshow.m'
-    'ain+xml')
-CT_TABLE_STYLES = (
-    'application/vnd.openxmlformats-officedocument.presentationml.tableStyles'
-    '+xml')
-CT_TAGS = (
-    'application/vnd.openxmlformats-officedocument.presentationml.tags+xml')
-CT_TEMPLATE = (
-    'application/vnd.openxmlformats-officedocument.presentationml.template.ma'
-    'in+xml')
-CT_THEME = (
-    'application/vnd.openxmlformats-officedocument.theme+xml')
-CT_VIEW_PROPS = (
-    'application/vnd.openxmlformats-officedocument.presentationml.viewProps+x'
-    'ml')
-CT_WORKSHEET = (
-    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet')
-
-
-RT_CHART = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/char'
-    't')
-RT_COMMENT_AUTHORS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/comm'
-    'entAuthors')
-RT_COMMENTS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/comm'
-    'ents')
-RT_CORE_PROPS = (
-    'http://schemas.openxmlformats.org/package/2006/relationships/metadata/co'
-    're-properties'
-)
-RT_CUSTOM_PROPS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/cust'
-    'omProperties'
-)
-RT_CUSTOM_XML = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/cus'
-    'tomXml'
-)
-RT_CUSTOM_XML_PROPS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/cus'
-    'tomXmlProps'
-)
-RT_EXTENDED_PROPS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/exte'
-    'ndedProperties')
-RT_HANDOUT_MASTER = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/hand'
-    'outMaster')
-RT_IMAGE = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/imag'
-    'e')
-RT_NOTES_MASTER = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/note'
-    'sMaster')
-RT_NOTES_SLIDE = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/note'
-    'sSlide')
-RT_OFFICE_DOCUMENT = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/offi'
-    'ceDocument')
-RT_PACKAGE = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/pack'
-    'age')
-RT_PRES_PROPS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/pres'
-    'Props')
-RT_PRINTER_SETTINGS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/prin'
-    'terSettings')
-RT_SLIDE = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/slid'
-    'e')
-RT_SLIDE_LAYOUT = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/slid'
-    'eLayout')
-RT_SLIDE_MASTER = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/slid'
-    'eMaster')
-RT_SLIDESHOW = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/offi'
-    'ceDocument')
-RT_TABLESTYLES = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/tabl'
-    'eStyles')
-RT_TAGS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/tags')
-RT_TEMPLATE = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/offi'
-    'ceDocument')
-RT_THEME = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/them'
-    'e')
-RT_VIEWPROPS = (
-    'http://schemas.openxmlformats.org/officeDocument/2006/relationships/view'
-    'Props')
-
 pml_parttypes = {
-    CT_COMMENT_AUTHORS: {  # ECMA-376-1 13.3.1
+    CT.DML_CHART: {  # ISO/IEC 29500-1 14.2.1
+        'basename':    'chart',
+        'ext':         '.xml',
+        'name':        'Chart Part',
+        'cardinality': PTS_CARDINALITY_TUPLE,
+        'required':    False,
+        'baseURI':     '/ppt/charts',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['presentation'],
+        'reltype':     RT.CHART
+    },
+    CT.PML_COMMENT_AUTHORS: {  # ECMA-376-1 13.3.1
         'basename':    'commentAuthors',
         'ext':         '.xml',
         'name':        'Comment Authors Part',
@@ -1702,8 +1517,9 @@ pml_parttypes = {
         'baseURI':     '/ppt',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['presentation'],
-        'reltype':     RT_COMMENT_AUTHORS},
-    CT_COMMENTS: {  # ECMA-376-1 13.3.2
+        'reltype':     RT.COMMENT_AUTHORS
+    },
+    CT.PML_COMMENTS: {  # ECMA-376-1 13.3.2
         'basename':    'comment',
         'ext':         '.xml',
         'name':        'Comments Part',
@@ -1712,8 +1528,9 @@ pml_parttypes = {
         'baseURI':     '/ppt/comments',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['slide'],
-        'reltype':     RT_COMMENTS},
-    CT_CORE_PROPS: {  # ECMA-376-1 15.2.12.1 ('Core' as in Dublin Core)
+        'reltype':     RT.COMMENTS
+    },
+    CT.OPC_CORE_PROPERTIES: {  # ECMA-376-1 15.2.12.1 ('Core' asin Dublin Core)
         'basename':    'core',
         'ext':         '.xml',
         'name':        'Core File Properties Part',
@@ -1722,8 +1539,9 @@ pml_parttypes = {
         'baseURI':     '/docProps',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['package'],
-        'reltype':     RT_CORE_PROPS},
-    CT_CUSTOM_PROPS: {  # ECMA-376-1 15.2.12.2
+        'reltype':     RT.CORE_PROPERTIES
+    },
+    CT.OFC_CUSTOM_PROPERTIES: {  # ECMA-376-1 15.2.12.2
         'basename':    'custom',
         'ext':         '.xml',
         'name':        'Custom File Properties Part',
@@ -1732,9 +1550,9 @@ pml_parttypes = {
         'baseURI':     '/docProps',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['package'],
-        'reltype':     RT_CUSTOM_PROPS
+        'reltype':     RT.CUSTOM_PROPERTIES
     },
-    CT_CUSTOM_XML: {  # ISO/IEC 29500-1 15.2.5
+    CT.XML: {  # ISO/IEC 29500-1 15.2.5
         'basename':    'item',
         'ext':         '.xml',
         'name':        'Custom XML Data Storage Part',
@@ -1743,9 +1561,9 @@ pml_parttypes = {
         'baseURI':     '/customXML',
         'has_rels':    PTS_HASRELS_OPTIONAL,
         'rels_from':   [],
-        'reltype':     RT_CUSTOM_XML
+        'reltype':     RT.CUSTOM_XML
     },
-    CT_CUSTOM_XML_PROPS: {  # ISO/IEC 29500-1 15.2.6
+    CT.OFC_CUSTOM_XML_PROPERTIES: {  # ISO/IEC 29500-1 15.2.6
         'basename':    'itemProps',
         'ext':         '.xml',
         'name':        'Custom XML Data Storage Properties Part',
@@ -1754,9 +1572,31 @@ pml_parttypes = {
         'baseURI':     '/customXML',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   [],
-        'reltype':     RT_CUSTOM_XML_PROPS
+        'reltype':     RT.CUSTOM_XML_PROPS
     },
-    CT_EXTENDED_PROPS: {  # ECMA-376-1 15.2.12.3 (Extended File Properties)
+    CT.WML_DOCUMENT_MAIN: {  # ISO/IEC 29500-1 11.3.10
+        'basename':    'document',
+        'ext':         '.xml',
+        'name':        'Main Document Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    True,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['package'],
+        'reltype':     RT.OFFICE_DOCUMENT
+    },
+    CT.WML_ENDNOTES: {  # ISO/IEC 29500-1 11.3.4
+        'basename':    'endnotes',
+        'ext':         '.xml',
+        'name':        'Endnotes Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document', 'glossary'],
+        'reltype':     RT.ENDNOTES
+    },
+    CT.OFC_EXTENDED_PROPERTIES: {  # ECMA-376-1 15.2.12.3
         'basename':    'app',
         'ext':         '.xml',
         'name':        'Application-Defined File Properties Part',
@@ -1765,8 +1605,53 @@ pml_parttypes = {
         'baseURI':     '/docProps',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['package'],
-        'reltype':     RT_EXTENDED_PROPS},
-    CT_HANDOUT_MASTER: {  # ECMA-376-1 13.3.3
+        'reltype':     RT.EXTENDED_PROPERTIES
+    },
+    CT.WML_FONT_TABLE: {  # ISO/IEC 29500-1 11.3.5
+        'basename':    'fontTable',
+        'ext':         '.xml',
+        'name':        'Font Table Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document'],
+        'reltype':     RT.FONT_TABLE
+    },
+    CT.WML_FOOTER: {  # ISO/IEC 29500-1 11.3.6
+        'basename':    'footer',
+        'ext':         '.xml',
+        'name':        'Footer Part',
+        'cardinality': PTS_CARDINALITY_TUPLE,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document', 'glossary'],
+        'reltype':     RT.FOOTER
+    },
+    CT.WML_FOOTNOTES: {  # ISO/IEC 29500-1 11.3.7
+        'basename':    'footnotes',
+        'ext':         '.xml',
+        'name':        'Footnotes Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document'],
+        'reltype':     RT.FOOTNOTES
+    },
+    CT.WML_DOCUMENT_GLOSSARY: {  # ISO/IEC 29500-1 11.3.8
+        'basename':    'document',
+        'ext':         '.xml',
+        'name':        'Glossary Document Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word/glossary',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document'],
+        'reltype':     RT.GLOSSARY_DOCUMENT
+    },
+    CT.PML_HANDOUT_MASTER: {  # ECMA-376-1 13.3.3
         'basename':    'handoutMaster',
         'ext':         '.xml',
         'name':        'Handout Master Part',
@@ -1777,8 +1662,20 @@ pml_parttypes = {
         'baseURI':     '/ppt/handoutMasters',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['presentation'],
-        'reltype':     RT_HANDOUT_MASTER},
-    CT_NOTES_MASTER: {  # ECMA-376-1 13.3.4
+        'reltype':     RT.HANDOUT_MASTER
+    },
+    CT.WML_HEADER: {  # ISO/IEC 29500-1 11.3.9
+        'basename':    'header',
+        'ext':         '.xml',
+        'name':        'Header Part',
+        'cardinality': PTS_CARDINALITY_TUPLE,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document', 'glossary'],
+        'reltype':     RT.HEADER
+    },
+    CT.PML_NOTES_MASTER: {  # ECMA-376-1 13.3.4
         'basename':    'notesMaster',
         'ext':         '.xml',
         'name':        'Notes Master Part',
@@ -1789,8 +1686,9 @@ pml_parttypes = {
         'baseURI':     '/ppt/notesMasters',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['presentation', 'notesSlide'],
-        'reltype':     RT_NOTES_MASTER},
-    CT_NOTES_SLIDE: {  # ECMA-376-1 13.3.5
+        'reltype':     RT.NOTES_MASTER
+    },
+    CT.PML_NOTES_SLIDE: {  # ECMA-376-1 13.3.5
         'basename':    'notesSlide',
         'ext':         '.xml',
         'name':        'Notes Slide Part',
@@ -1799,8 +1697,20 @@ pml_parttypes = {
         'baseURI':     '/ppt/notesSlides',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['slide'],
-        'reltype':     RT_NOTES_SLIDE},
-    CT_PRESENTATION: {  # ECMA-376-1 13.3.6
+        'reltype':     RT.NOTES_SLIDE
+    },
+    CT.WML_NUMBERING: {  # ISO/IEC 29500-1 11.3.11
+        'basename':    'numbering',
+        'ext':         '.xml',
+        'name':        'Numbering Definitions Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document'],
+        'reltype':     RT.NUMBERING
+    },
+    CT.PML_PRESENTATION_MAIN: {  # ECMA-376-1 13.3.6
         # one of three possible Content Type values for presentation part
         'basename':    'presentation',
         'ext':         '.xml',
@@ -1810,8 +1720,9 @@ pml_parttypes = {
         'baseURI':     '/ppt',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['package'],
-        'reltype':     RT_OFFICE_DOCUMENT},
-    CT_PRES_PROPS: {  # ECMA-376-1 13.3.7
+        'reltype':     RT.OFFICE_DOCUMENT
+    },
+    CT.PML_PRES_PROPS: {  # ECMA-376-1 13.3.7
         'basename':    'presProps',
         'ext':         '.xml',
         'name':        'Presentation Properties Part',
@@ -1820,8 +1731,9 @@ pml_parttypes = {
         'baseURI':     '/ppt',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['presentation'],
-        'reltype':     RT_PRES_PROPS},
-    CT_PRINTER_SETTINGS: {  # ECMA-376-1 15.2.15
+        'reltype':     RT.PRES_PROPS
+    },
+    CT.PML_PRINTER_SETTINGS: {  # ECMA-376-1 15.2.15
         'basename':    'printerSettings',
         'ext':         '.bin',
         'name':        'Printer Settings Part',
@@ -1830,8 +1742,20 @@ pml_parttypes = {
         'baseURI':     '/ppt/printerSettings',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['presentation'],
-        'reltype':     RT_PRINTER_SETTINGS},
-    CT_SLIDE: {  # ECMA-376-1 13.3.8
+        'reltype':     RT.PRINTER_SETTINGS
+    },
+    CT.WML_SETTINGS: {  # ISO/IEC 29500-1 11.3.3
+        'basename':    'settings',
+        'ext':         '.xml',
+        'name':        'Document Settings Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document', 'glossary'],
+        'reltype':     RT.SETTINGS
+    },
+    CT.PML_SLIDE: {  # ECMA-376-1 13.3.8
         'basename':    'slide',
         'ext':         '.xml',
         'name':        'Slide Part',
@@ -1840,8 +1764,9 @@ pml_parttypes = {
         'baseURI':     '/ppt/slides',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['presentation', 'notesSlide'],
-        'reltype':     RT_SLIDE},
-    CT_SLIDE_LAYOUT: {  # ECMA-376-1 13.3.9
+        'reltype':     RT.SLIDE
+    },
+    CT.PML_SLIDE_LAYOUT: {  # ECMA-376-1 13.3.9
         'basename':    'slideLayout',
         'ext':         '.xml',
         'name':        'Slide Layout Part',
@@ -1850,8 +1775,9 @@ pml_parttypes = {
         'baseURI':     '/ppt/slideLayouts',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['slide', 'slideMaster'],
-        'reltype':     RT_SLIDE_LAYOUT},
-    CT_SLIDE_MASTER: {  # ECMA-376-1 13.3.10
+        'reltype':     RT.SLIDE_LAYOUT
+    },
+    CT.PML_SLIDE_MASTER: {  # ECMA-376-1 13.3.10
         'basename':    'slideMaster',
         'ext':         '.xml',
         'name':        'Slide Master Part',
@@ -1860,8 +1786,9 @@ pml_parttypes = {
         'baseURI':     '/ppt/slideMasters',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['presentation', 'slideLayout'],
-        'reltype':     RT_SLIDE_MASTER},
-    CT_SLIDESHOW: {  # ECMA-376-1 13.3.6
+        'reltype':     RT.SLIDE_MASTER
+    },
+    CT.PML_SLIDESHOW_MAIN: {  # ECMA-376-1 13.3.6
         # one of three possible Content Type values for presentation part
         'basename':    'presentation',
         'ext':         '.xml',
@@ -1871,8 +1798,20 @@ pml_parttypes = {
         'baseURI':     '/ppt',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['package'],
-        'reltype':     RT_SLIDESHOW},
-    CT_TABLE_STYLES: {  # ECMA-376-1 14.2.9
+        'reltype':     RT.OFFICE_DOCUMENT
+    },
+    CT.WML_STYLES: {  # ISO/IEC 29500-1 11.3.12
+        'basename':    'styles',
+        'ext':         '.xml',
+        'name':        'Style Definitions Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_NEVER,
+        'rels_from':   ['document'],
+        'reltype':     RT.STYLES
+    },
+    CT.PML_TABLE_STYLES: {  # ECMA-376-1 14.2.9
         'basename':    'tableStyles',
         'ext':         '.xml',
         'name':        'Table Styles Part',
@@ -1881,8 +1820,9 @@ pml_parttypes = {
         'baseURI':     '/ppt',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['presentation'],
-        'reltype':     RT_TABLESTYLES},
-    CT_TAGS: {  # ECMA-376-1 13.3.12
+        'reltype':     RT.TABLE_STYLES
+    },
+    CT.PML_TAGS: {  # ECMA-376-1 13.3.12
         'basename':    'tag',
         'ext':         '.xml',
         'name':        'User-Defined Tags Part',
@@ -1891,8 +1831,9 @@ pml_parttypes = {
         'baseURI':     '/ppt/tags',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['presentation', 'slide'],
-        'reltype':     RT_TAGS},
-    CT_TEMPLATE: {  # ECMA-376-1 13.3.6
+        'reltype':     RT.TAGS
+    },
+    CT.PML_TEMPLATE_MAIN: {  # ECMA-376-1 13.3.6
         # one of three possible Content Type values for presentation part
         'basename':    'presentation',
         'ext':         '.xml',
@@ -1902,8 +1843,9 @@ pml_parttypes = {
         'baseURI':     '/ppt',
         'has_rels':    PTS_HASRELS_ALWAYS,
         'rels_from':   ['package'],
-        'reltype':     RT_TEMPLATE},
-    CT_THEME: {  # ECMA-376-1 14.2.7
+        'reltype':     RT.OFFICE_DOCUMENT
+    },
+    CT.OFC_THEME: {  # ECMA-376-1 14.2.7
         'basename':    'theme',
         'ext':         '.xml',
         'name':        'Theme Part',
@@ -1916,8 +1858,9 @@ pml_parttypes = {
         'has_rels':    PTS_HASRELS_OPTIONAL,
         'rels_from':   ['presentation', 'handoutMaster', 'notesMaster',
                         'slideMaster'],
-        'reltype':     RT_THEME},
-    CT_VIEW_PROPS: {  # ECMA-376-1 13.3.13
+        'reltype':     RT.THEME
+    },
+    CT.PML_VIEW_PROPS: {  # ECMA-376-1 13.3.13
         'basename':    'viewProps',
         'ext':         '.xml',
         'name':        'View Properties Part',
@@ -1926,7 +1869,41 @@ pml_parttypes = {
         'baseURI':     '/ppt',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['presentation'],
-        'reltype':     RT_VIEWPROPS
+        'reltype':     RT.VIEW_PROPS
+    },
+    CT.WML_WEB_SETTINGS: {  # ISO/IEC 29500-1 11.3.13
+        'basename':    'webSettings',
+        'ext':         '.xml',
+        'name':        'Web Settings Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document', 'glossary'],
+        'reltype':     RT.WEB_SETTINGS
+    },
+    CT.WML_COMMENTS: {  # ISO/IEC 29500-1 11.3.2
+        'basename':    'comments',
+        'ext':         '.xml',
+        'name':        'Comments Part',
+        'cardinality': PTS_CARDINALITY_SINGLETON,
+        'required':    False,
+        'baseURI':     '/word',
+        'has_rels':    PTS_HASRELS_OPTIONAL,
+        'rels_from':   ['document'],
+        'reltype':     RT.COMMENTS
+    },
+    'image/bmp': {  # ECMA-376-1 15.2.14
+        'basename':    'image',
+        'ext':         '.bmp',
+        'name':        'Image Part',
+        'cardinality': PTS_CARDINALITY_TUPLE,
+        'required':    False,
+        'baseURI':     '/ppt/media',
+        'has_rels':    PTS_HASRELS_NEVER,
+        'rels_from':   ['handoutMaster', 'notesSlide', 'notesMaster', 'slide',
+                        'slideLayout', 'slideMaster'],
+        'reltype':     RT.IMAGE
     },
     'image/gif': {  # ECMA-376-1 15.2.14
         'basename':    'image',
@@ -1938,7 +1915,8 @@ pml_parttypes = {
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['handoutMaster', 'notesSlide', 'notesMaster', 'slide',
                         'slideLayout', 'slideMaster'],
-        'reltype':     RT_IMAGE},
+        'reltype':     RT.IMAGE
+    },
     'image/jpeg': {  # ECMA-376-1 15.2.14
         'basename':    'image',
         'ext':         '.jpeg',
@@ -1949,7 +1927,8 @@ pml_parttypes = {
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['handoutMaster', 'notesSlide', 'notesMaster', 'slide',
                         'slideLayout', 'slideMaster'],
-        'reltype':     RT_IMAGE},
+        'reltype':     RT.IMAGE
+    },
     'image/png': {  # ECMA-376-1 15.2.14
         'basename':    'image',
         'ext':         '.png',
@@ -1960,29 +1939,7 @@ pml_parttypes = {
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   ['handoutMaster', 'notesSlide', 'notesMaster', 'slide',
                         'slideLayout', 'slideMaster'],
-        'reltype':     RT_IMAGE},
-    'image/x-emf': {  # ECMA-376-1 15.2.14
-        'basename':    'image',
-        'ext':         '.emf',
-        'name':        'Image Part',
-        'cardinality': PTS_CARDINALITY_TUPLE,
-        'required':    False,
-        'baseURI':     '/ppt/media',
-        'has_rels':    PTS_HASRELS_NEVER,
-        'rels_from':   ['handoutMaster', 'notesSlide', 'notesMaster', 'slide',
-                        'slideLayout', 'slideMaster'],
-        'reltype':     RT_IMAGE
-    },
-    'image/vnd.ms-photo': {
-        'basename':    'hdphoto',
-        'ext':         '.wdp',
-        'name':        'Image Part',
-        'cardinality': PTS_CARDINALITY_TUPLE,
-        'required':    False,
-        'baseURI':     '/ppt/media',
-        'has_rels':    PTS_HASRELS_NEVER,
-        'rels_from':   [],
-        'reltype':     RT_IMAGE
+        'reltype':     RT.IMAGE
     },
     'image/tiff': {
         'basename':    'image',
@@ -1993,8 +1950,54 @@ pml_parttypes = {
         'baseURI':     '/ppt/media',
         'has_rels':    PTS_HASRELS_NEVER,
         'rels_from':   [],
-        'reltype':     RT_IMAGE
-    }
+        'reltype':     RT.IMAGE
+    },
+    'image/vnd.ms-photo': {
+        'basename':    'hdphoto',
+        'ext':         '.wdp',
+        'name':        'Image Part',
+        'cardinality': PTS_CARDINALITY_TUPLE,
+        'required':    False,
+        'baseURI':     '/ppt/media',
+        'has_rels':    PTS_HASRELS_NEVER,
+        'rels_from':   [],
+        'reltype':     RT.IMAGE
+    },
+    'image/x-emf': {  # ECMA-376-1 15.2.14
+        'basename':    'image',
+        'ext':         '.emf',
+        'name':        'Image Part',
+        'cardinality': PTS_CARDINALITY_TUPLE,
+        'required':    False,
+        'baseURI':     '/ppt/media',
+        'has_rels':    PTS_HASRELS_NEVER,
+        'rels_from':   ['handoutMaster', 'notesSlide', 'notesMaster', 'slide',
+                        'slideLayout', 'slideMaster'],
+        'reltype':     RT.IMAGE
+    },
+    'image/x-wmf': {
+        'basename':    'image',
+        'ext':         '.wmf',
+        'name':        'Image Part',
+        'cardinality': PTS_CARDINALITY_TUPLE,
+        'required':    False,
+        'baseURI':     '/ppt/media',
+        'has_rels':    PTS_HASRELS_NEVER,
+        'rels_from':   ['handoutMaster', 'notesSlide', 'notesMaster',
+                        'slide', 'slideLayout', 'slideMaster'],
+        'reltype':     RT.IMAGE,
+    },
+    'application/x-fontdata': {
+        'basename':    'font',
+        'ext':         '.fntdata',
+        'name':        'Font Part',
+        'cardinality': PTS_CARDINALITY_TUPLE,
+        'required':    False,
+        'baseURI':     '/ppt/fonts',
+        'has_rels':    PTS_HASRELS_NEVER,
+        'rels_from':   ['presentation'],
+        'reltype':     RT.FONT,
+    },
 }
 
 
@@ -2010,7 +2013,8 @@ pml_parttypes = {
 # ============================================================================
 
 default_content_types = {
-    '.bin':     CT_PRINTER_SETTINGS,
+    '.bin':     CT.PML_PRINTER_SETTINGS,
+    '.bmp':     'image/bmp',
     '.emf':     'image/x-emf',
     '.fntdata': 'application/x-fontdata',
     '.gif':     'image/gif',
@@ -2023,72 +2027,6 @@ default_content_types = {
     '.tiff':    'image/tiff',
     '.wdp':     'image/vnd.ms-photo',
     '.wmf':     'image/x-wmf',
-    '.xlsx':    CT_EXCEL_XLSX,
+    '.xlsx':    CT.SML_SHEET,
     '.xml':     'application/xml'
 }
-
-
-# ============================================================================
-# nsmap
-# ============================================================================
-# namespace prefix to namespace name map
-# ============================================================================
-
-nsmap = {
-    'a':   'http://schemas.openxmlformats.org/drawingml/2006/main',
-    'cp':  ('http://schemas.openxmlformats.org/package/2006/metadata/core-pro'
-            'perties'),
-    'ct':  'http://schemas.openxmlformats.org/package/2006/content-types',
-    'dc':  'http://purl.org/dc/elements/1.1/',
-    'dcmitype': 'http://purl.org/dc/dcmitype/',
-    'dcterms':  'http://purl.org/dc/terms/',
-    'ep':  ('http://schemas.openxmlformats.org/officeDocument/2006/extended-p'
-            'roperties'),
-    'i':   RT_IMAGE,
-    'm':   'http://schemas.openxmlformats.org/officeDocument/2006/math',
-    'mo':  'http://schemas.microsoft.com/office/mac/office/2008/main',
-    'mv':  'urn:schemas-microsoft-com:mac:vml',
-    'o':   'urn:schemas-microsoft-com:office:office',
-    'p':   'http://schemas.openxmlformats.org/presentationml/2006/main',
-    'pd':  ('http://schemas.openxmlformats.org/drawingml/2006/presentationDra'
-            'wing'),
-    'pic': 'http://schemas.openxmlformats.org/drawingml/2006/picture',
-    'pr':  'http://schemas.openxmlformats.org/package/2006/relationships',
-    'r':   ('http://schemas.openxmlformats.org/officeDocument/2006/relationsh'
-            'ips'),
-    'sl':  ('http://schemas.openxmlformats.org/officeDocument/2006/relationsh'
-            'ips/slideLayout'),
-    'v':   'urn:schemas-microsoft-com:vml',
-    've':  'http://schemas.openxmlformats.org/markup-compatibility/2006',
-    'w':   'http://schemas.openxmlformats.org/wordprocessingml/2006/main',
-    'w10': 'urn:schemas-microsoft-com:office:word',
-    'wne': 'http://schemas.microsoft.com/office/word/2006/wordml',
-    'wp':  ('http://schemas.openxmlformats.org/drawingml/2006/wordprocessingD'
-            'rawing'),
-    'xsi': 'http://www.w3.org/2001/XMLSchema-instance'}
-
-
-def namespaces(*prefixes):
-    """
-    Return a dict containing the subset namespace prefix mappings specified by
-    *prefixes*. Any number of namespace prefixes can be supplied, e.g.
-    namespaces('a', 'r', 'p').
-    """
-    namespaces = {}
-    for prefix in prefixes:
-        namespaces[prefix] = nsmap[prefix]
-    return namespaces
-
-
-def qtag(tag):
-    """
-    Return a qualified name (QName) for an XML element or attribute in Clark
-    notation, e.g. ``'{http://www.w3.org/1999/xhtml}body'`` instead of
-    ``'html:body'``, by looking up the specified namespace prefix in the
-    overall namespace map (nsmap) above. Google on "xml clark notation" for
-    more on Clark notation. *tag* is a namespace-prefixed tagname, e.g.
-    ``'p:cSld'``.
-    """
-    prefix, tagroot = tag.split(':')
-    uri = nsmap[prefix]
-    return '{%s}%s' % (uri, tagroot)
