@@ -1,20 +1,11 @@
-# -*- coding: utf-8 -*-
-#
-# util.py
-#
-# Copyright (C) 2012, 2013 Steve Canny scanny@cisco.com
-#
-# This module is part of python-pptx and is released under
-# the MIT License: http://www.opensource.org/licenses/mit-license.php
+# encoding: utf-8
 
 """
 Utility functions and classes that come in handy when working with PowerPoint
 and Open XML.
 """
 
-import os
 import platform
-import re
 
 
 class _BaseLength(int):
@@ -107,95 +98,68 @@ class Collection(object):
     """
     def __init__(self):
         super(Collection, self).__init__()
-        self.__values = []
+        self._values_ = []
 
     @property
     def _values(self):
         """Return read-only reference to collection values (list)."""
-        return self.__values
+        return self._values_
 
     def __contains__(self, item):  # __iter__ would do this job by itself
         """Supports 'in' operator (e.g. 'x in collection')."""
-        return (item in self.__values)
+        return (item in self._values_)
 
     def __getitem__(self, key):
         """Provides indexed access, (e.g. 'collection[0]')."""
-        return self.__values.__getitem__(key)
+        return self._values_.__getitem__(key)
 
     def __iter__(self):
         """Supports iteration (e.g. 'for x in collection: pass')."""
-        return self.__values.__iter__()
+        return self._values_.__iter__()
 
     def __len__(self):
         """Supports len() function (e.g. 'len(collection) == 1')."""
-        return len(self.__values)
+        return len(self._values_)
 
     def index(self, item):
         """Supports index method (e.g. '[1, 2, 3].index(2) == 1')."""
-        return self.__values.index(item)
+        return self._values_.index(item)
 
 
-class Partname(object):
+def lazyproperty(f):
     """
-    Provides access to partname components such as the baseURI and the part
-    index.
+    @lazyprop decorator. Decorated method will be called only on first access
+    to calculate a cached property value. After that, the cached value is
+    returned.
     """
-    __filename_re = re.compile('([a-zA-Z]+)([1-9][0-9]*)?')
+    cache_attr_name = '_%s' % f.__name__  # like '_foobar' for prop 'foobar'
+    docstring = f.__doc__
 
-    def __init__(self, partname):
-        super(Partname, self).__init__()
-        self.__partname = partname
+    def get_prop_value(obj):
+        try:
+            return getattr(obj, cache_attr_name)
+        except AttributeError:
+            value = f(obj)
+            setattr(obj, cache_attr_name, value)
+            return value
 
-    @property
-    def baseURI(self):
-        """
-        The base URI of partname, e.g. ``'/ppt/slides'`` for
-        ``'/ppt/slides/slide1.xml'``.
-        """
-        return os.path.split(self.__partname)[0]
+    return property(get_prop_value, doc=docstring)
 
-    @property
-    def filename(self):
-        """
-        The "filename" portion of partname, e.g. ``'slide1.xml'`` for
-        ``'/ppt/slides/slide1.xml'``.
-        """
-        return os.path.split(self.__partname)[1]
 
-    @property
-    def ext(self):
-        """
-        The extension portion of partname, e.g. ``'.xml'`` for
-        ``'/ppt/slides/slide1.xml'``. Note that period is included, consistent
-        with behavior of :meth:`os.path.ext`.
-        """
-        return os.path.splitext(self.__partname)[1]
+def to_unicode(text):
+    """
+    Return *text* as a unicode string.
 
-    @property
-    def partname(self):
-        """
-        The complete partname, e.g. ``'/ppt/slides/slide1.xml'`` for
-        ``'/ppt/slides/slide1.xml'``.
-        """
-        return self.__partname
-
-    @property
-    def basename(self):
-        """
-        The base "filename" of the partname, e.g. ``'slide'`` for
-        ``'/ppt/slides/slide1.xml'``.
-        """
-        name = os.path.splitext(self.filename)[0]  # filename with ext removed
-        match = self.__filename_re.match(name)
-        return match.group(1)
-
-    @property
-    def idx(self):
-        """
-        Return partname index as integer for tuple partname or None for
-        singleton partname, e.g. ``21`` for ``'/ppt/slides/slide21.xml'`` and
-        |None| for ``'/ppt/presentation.xml'``.
-        """
-        name = os.path.splitext(self.filename)[0]  # filename with ext removed
-        match = self.__filename_re.match(name)
-        return int(match.group(2)) if match.group(2) else None
+    *text* can be a 7-bit ASCII string, a UTF-8 encoded 8-bit string, or
+    unicode. String values are converted to unicode assuming UTF-8 encoding.
+    Unicode values are returned unchanged.
+    """
+    # both str and unicode inherit from basestring
+    if not isinstance(text, basestring):
+        tmpl = 'expected UTF-8 encoded string or unicode, got %s value %s'
+        raise TypeError(tmpl % (type(text), text))
+    # return unicode strings unchanged
+    if isinstance(text, unicode):
+        return text
+    # otherwise assume UTF-8 encoding, which also works for ASCII
+    return unicode(text, 'utf-8')
